@@ -83,14 +83,15 @@ using namespace tlp;
 // ill-formed utf8 chars (ascii or windows 1252 chars)
 // latex special chars
 // and to replace them by the corresponding utf8 sequence
-static char *utf8seq;
-static char *seq(char cc[2]) {
-  return utf8seq = cc;
+static char utf8seq[2];
+static void seq(char c0, char c1) {
+  utf8seq[0] = c0;
+  utf8seq[1] = c1;
 }
 static string &forceUtf8String(string &str) {
-  char c3[2] = {'\303', ' '};
-  char c4[2] = {'\304', ' '};
-  char c5[2] = {'\305', ' '};
+  char c3 = '\303';
+  char c4 = '\304';
+  char c5 = '\305';
   char charComposing = 0;
 
   for (unsigned int i = 0; i < str.size(); ++i) {
@@ -115,184 +116,184 @@ static string &forceUtf8String(string &str) {
     // é
     case '\202': // extended ascii
     case '\351': // windows 1252
-      seq(c3)[1] = '\251';
+      seq(c3, '\251');
       break;
 
     // ê
     case '\210': // extended ascii
     case '\352': // windows 1252
-      seq(c3)[1] = '\252';
+      seq(c3, '\252');
       break;
 
     // ë
     case '\211': // extended ascii
     case '\353': // windows 1252
-      seq(c3)[1] = '\253';
+      seq(c3, '\253');
       break;
 
     // è
     case '\212': // extended ascii
     case '\350': // windows 1252
-      seq(c3)[1] = '\250';
+      seq(c3, '\250');
       break;
 
     // á
     case '\240': // extended ascii
     case '\341': // windows 1252
-      seq(c3)[1] = '\241';
+      seq(c3, '\241');
       break;
 
     // â
     case '\203': // extended ascii
     case '\342': // windows 1252
-      seq(c3)[1] = '\242';
+      seq(c3, '\242');
       break;
 
     // ä
     case '\204': // extended ascii
     case '\344': // windows 1252
-      seq(c3)[1] = '\244';
+      seq(c3, '\244');
       break;
 
     // à
     case '\205': // extended ascii
     case '\340': // windows 1252
-      seq(c3)[1] = '\240';
+      seq(c3, '\240');
       break;
 
     // å
     case '\206': // extended ascii
     case '\345': // windows 1252
-      seq(c3)[1] = '\245';
+      seq(c3, '\245');
       break;
 
     // ã
     case '\343': // windows 1252
-      seq(c3)[1] = '\243';
+      seq(c3, '\243');
       break;
 
     // ï
     case '\213': // extended ascii
     case '\357': // windows 1252
-      seq(c3)[1] = '\257';
+      seq(c3, '\257');
       break;
 
     // î
     case '\214': // extended ascii
     case '\356': // windows 1252
-      seq(c3)[1] = '\256';
+      seq(c3, '\256');
       break;
 
     // ì
     case '\215': // extended ascii
     case '\354': // windows 1252
-      seq(c3)[1] = '\254';
+      seq(c3, '\254');
       break;
 
     // í
     case '\241': // extended ascii
     case '\355': // windows 1252
-      seq(c3)[1] = '\255';
+      seq(c3, '\255');
       break;
 
     // ô
     case '\223': // extended ascii
     case '\364': // windows 1252
-      seq(c3)[1] = '\264';
+      seq(c3, '\264');
       break;
 
     // ö
     case '\224': // extended ascii
     case '\366': // windows 1252
-      seq(c3)[1] = '\266';
+      seq(c3, '\266');
       break;
 
     // ò
     case '\225': // extended ascii
     case '\362': // windows 1252
-      seq(c3)[1] = '\262';
+      seq(c3, '\262');
       break;
 
     // ø
     case '\233': // extended ascii
     case '\370': // windows 1252
-      seq(c3)[1] = '\270';
+      seq(c3, '\270');
       break;
 
     // õ
     case '\365': // windows 1252
-      seq(c3)[1] = '\265';
+      seq(c3, '\265');
       break;
 
     // ó
     case '\242': // extended ascii
     case '\363': // windows 1252
-      seq(c3)[1] = '\263';
+      seq(c3, '\263');
       break;
 
     // ü
     case '\201': // extended ascii
     case '\374': // windows 1252
-      seq(c3)[1] = '\274';
+      seq(c3, '\274');
       break;
 
     // û
     case '\226': // extended ascii
     case '\373': // windows 1252
-      seq(c3)[1] = '\273';
+      seq(c3, '\273');
       break;
 
     // ù
     case '\227': // extended ascii
     case '\371': // windows 1252
-      seq(c3)[1] = '\271';
+      seq(c3, '\271');
       break;
 
     // ú
     case '\243': // extended ascii
     case '\372': // windows 1252
-      seq(c3)[1] = '\272';
+      seq(c3, '\272');
       break;
 
     // ÿ
     case '\230': // extended ascii
     case '\377': // windows 1252
-      seq(c3)[1] = '\277';
+      seq(c3, '\277');
       break;
 
     // ç
     case '\347': // extended ascii & windows 1252
-      seq(c3)[1] = '\247';
+      seq(c3, '\247');
       break;
 
     // ñ
     case '\244': // extended ascii
     case '\361': // windows 1252
-      seq(c3)[1] = '\261';
+      seq(c3, '\261');
       break;
 
     // É
     case '\220': // extended ascii
     case '\311': // windows 1252
-      seq(c3)[1] = '\211';
+      seq(c3, '\211');
       break;
 
     // Ê
     case '\322': // extended ascii
     case '\312': // windows 1252
-      seq(c3)[1] = '\212';
+      seq(c3, '\212');
       break;
 
     // Ë
     case '\323': // extended ascii
     case '\313': // windows 1252
-      seq(c3)[1] = '\213';
+      seq(c3, '\213');
       break;
 
     // È
     case '\324': // extended ascii
     case '\310': // windows 1252
-      seq(c3)[1] = '\210';
+      seq(c3, '\210');
       break;
 
     // ß
@@ -300,7 +301,7 @@ static string &forceUtf8String(string &str) {
     // but is also the windows 1252 code of á
     // case '\341': // extended ascii
     case '\337': // windows 1252
-      seq(c3)[1] = '\237';
+      seq(c3, '\237');
       break;
 
     case '\303': // begin of a 2 bytes utf8 char
@@ -320,31 +321,31 @@ static string &forceUtf8String(string &str) {
         if (str[i + 1] == 'i')
           switch (charComposing) {
           case '`': // ì
-            seq(c3)[1] = '\254';
+            seq(c3, '\254');
             break;
 
           case '\'': // í
-            seq(c3)[1] = '\255';
+            seq(c3, '\255');
             break;
 
           case '^': // î
-            seq(c3)[1] = '\256';
+            seq(c3, '\256');
             break;
 
           case '"': // ï
-            seq(c3)[1] = '\257';
+            seq(c3, '\257');
             break;
 
           case '~': // ĩ
-            seq(c4)[1] = '\251';
+            seq(c4, '\251');
             break;
 
           case '=': // ī
-            seq(c4)[1] = '\253';
+            seq(c4, '\253');
             break;
 
           case 'u': // ĭ
-            seq(c4)[1] = '\254';
+            seq(c4, '\254');
             break;
 
           default:
@@ -381,8 +382,8 @@ static string &forceUtf8String(string &str) {
       case 'a':
         if (str.size() > i + 2 && str[i + 2] == 'e') {
           // replace by æ
-          c3[1] = '\246';
-          str.replace(i, 3, c3, 2);
+          seq(c3, '\246');
+          str.replace(i, 3, utf8seq, 2);
           ++i;
         }
 
@@ -391,8 +392,8 @@ static string &forceUtf8String(string &str) {
       case 'A':
         if (str.size() > i + 2 && str[i + 2] == 'E') {
           // replace by Æ
-          c3[1] = '\206';
-          str.replace(i, 3, c3, 2);
+          seq(c3, '\206');
+          str.replace(i, 3, utf8seq, 2);
           ++i;
         }
 
@@ -400,22 +401,22 @@ static string &forceUtf8String(string &str) {
 
       case 'd':
         // replace by đ
-        c4[1] = '\221';
-        str.replace(i, 2, c4, 2);
+        seq(c4, '\221');
+        str.replace(i, 2, utf8seq, 2);
         ++i;
         continue;
 
       case 'D':
         // replace by Đ
-        c4[1] = '\220';
-        str.replace(i, 2, c4, 2);
+        seq(c4, '\220');
+        str.replace(i, 2, utf8seq, 2);
         ++i;
         continue;
 
       case 'h':
         // replace by ħ
-        c4[1] = '\247';
-        str.replace(i, 2, c4, 2);
+        seq(c4, '\247');
+        str.replace(i, 2, utf8seq, 2);
         ++i;
         continue;
 
@@ -423,26 +424,26 @@ static string &forceUtf8String(string &str) {
         if (str.size() > i + 2) {
           switch (str[i + 2]) {
           case '0': // Ő
-            seq(c5)[1] = '\220';
-            str.replace(i, 3, c5, 2);
+            seq(c5, '\220');
+            str.replace(i, 3, utf8seq, 2);
             ++i;
             continue;
 
           case 'o': // ő
-            seq(c5)[1] = '\221';
-            str.replace(i, 3, c5, 2);
+            seq(c5, '\221');
+            str.replace(i, 3, utf8seq, 2);
             ++i;
             continue;
 
           case 'U': // Ű
-            seq(c5)[1] = '\260';
-            str.replace(i, 3, c5, 2);
+            seq(c5, '\260');
+            str.replace(i, 3, utf8seq, 2);
             ++i;
             continue;
 
           case 'u': // ű
-            seq(c5)[1] = '\261';
-            str.replace(i, 3, c5, 2);
+            seq(c5, '\261');
+            str.replace(i, 3, utf8seq, 2);
             ++i;
             continue;
 
@@ -452,34 +453,34 @@ static string &forceUtf8String(string &str) {
         }
 
         // replace by Ħ
-        c4[1] = '\246';
-        str.replace(i, 2, c4, 2);
+        seq(c4, '\246');
+        str.replace(i, 2, utf8seq, 2);
         ++i;
         continue;
 
       case 'l':
         // replace by ł
-        c5[1] = '\202';
-        str.replace(i, 2, c5, 2);
+        seq(c5, '\202');
+        str.replace(i, 2, utf8seq, 2);
         ++i;
         continue;
 
       case 'L':
         // replace by Ł
-        c5[1] = '\201';
-        str.replace(i, 2, c5, 2);
+        seq(c5, '\201');
+        str.replace(i, 2, utf8seq, 2);
         ++i;
         continue;
 
       case 'o':
         if (str.size() > i + 2 && str[i + 2] == 'e') {
           // replace by œ
-          c5[1] = '\223';
-          str.replace(i, 3, c5, 2);
+          seq(c5, '\223');
+          str.replace(i, 3, utf8seq, 2);
         } else {
           // replace by ø
-          c3[1] = '\270';
-          str.replace(i, 2, c3, 2);
+          seq(c3, '\270');
+          str.replace(i, 2, utf8seq, 2);
         }
 
         ++i;
@@ -488,12 +489,12 @@ static string &forceUtf8String(string &str) {
       case 'O':
         if (str.size() > i + 2 && str[i + 2] == 'E') {
           // replace by Œ
-          c5[1] = '\222';
-          str.replace(i, 3, c5, 2);
+          seq(c5, '\222');
+          str.replace(i, 3, utf8seq, 2);
         } else {
           // replace by Ø
-          c3[1] = '\230';
-          str.replace(i, 2, c3, 2);
+          seq(c3, '\230');
+          str.replace(i, 2, utf8seq, 2);
         }
 
         ++i;
@@ -501,15 +502,15 @@ static string &forceUtf8String(string &str) {
 
       case 't':
         // replace by ŧ
-        c5[1] = '\245';
-        str.replace(i, 2, c5, 2);
+        seq(c5, '\245');
+        str.replace(i, 2, utf8seq, 2);
         ++i;
         continue;
 
       case 'T':
         // replace by Ŧ
-        c5[1] = '\246';
-        str.replace(i, 2, c5, 2);
+        seq(c5, '\246');
+        str.replace(i, 2, utf8seq, 2);
         ++i;
         continue;
 
@@ -530,39 +531,39 @@ static string &forceUtf8String(string &str) {
         case 'a':
           switch (charComposing) {
           case '`': // à
-            seq(c3)[1] = '\240';
+            seq(c3, '\240');
             break;
 
           case '\'': // á
-            seq(c3)[1] = '\241';
+            seq(c3, '\241');
             break;
 
           case '^': // â
-            seq(c3)[1] = '\242';
+            seq(c3, '\242');
             break;
 
           case '~': // ã
-            seq(c3)[1] = '\243';
+            seq(c3, '\243');
             break;
 
           case '"': // ä
-            seq(c3)[1] = '\244';
+            seq(c3, '\244');
             break;
 
           case 'r': // å
-            seq(c3)[1] = '\245';
+            seq(c3, '\245');
             break;
 
           case '=': // ā
-            seq(c4)[1] = '\201';
+            seq(c4, '\201');
             break;
 
           case 'u': // ă
-            seq(c4)[1] = '\203';
+            seq(c4, '\203');
             break;
 
           case 'k': // ą
-            seq(c4)[1] = '\205';
+            seq(c4, '\205');
             break;
 
           default:
@@ -574,23 +575,23 @@ static string &forceUtf8String(string &str) {
         case 'c':
           switch (charComposing) {
           case 'c': // ç
-            seq(c3)[1] = '\247';
+            seq(c3, '\247');
             break;
 
           case '\'': // ć
-            seq(c4)[1] = '\207';
+            seq(c4, '\207');
             break;
 
           case '^': // ĉ
-            seq(c4)[1] = '\211';
+            seq(c4, '\211');
             break;
 
           case '.': // ċ
-            seq(c4)[1] = '\213';
+            seq(c4, '\213');
             break;
 
           case 'v': // č
-            seq(c4)[1] = '\215';
+            seq(c4, '\215');
             break;
 
           default:
@@ -602,7 +603,7 @@ static string &forceUtf8String(string &str) {
         case 'd':
           if (charComposing == 'v') {
             // ď
-            seq(c4)[1] = '\217';
+            seq(c4, '\217');
             break;
           } else
             continue;
@@ -610,39 +611,39 @@ static string &forceUtf8String(string &str) {
         case 'e':
           switch (charComposing) {
           case '`': // è
-            seq(c3)[1] = '\250';
+            seq(c3, '\250');
             break;
 
           case '\'': // é
-            seq(c3)[1] = '\251';
+            seq(c3, '\251');
             break;
 
           case '^': // ê
-            seq(c3)[1] = '\252';
+            seq(c3, '\252');
             break;
 
           case '"': // ë
-            seq(c3)[1] = '\253';
+            seq(c3, '\253');
             break;
 
           case '=': // ë
-            seq(c4)[1] = '\223';
+            seq(c4, '\223');
             break;
 
           case 'u': // ĕ
-            seq(c4)[1] = '\225';
+            seq(c4, '\225');
             break;
 
           case '.': // ė
-            seq(c4)[1] = '\227';
+            seq(c4, '\227');
             break;
 
           case 'k': // ę
-            seq(c4)[1] = '\231';
+            seq(c4, '\231');
             break;
 
           case 'v': // ě
-            seq(c4)[1] = '\233';
+            seq(c4, '\233');
             break;
 
           default:
@@ -654,19 +655,19 @@ static string &forceUtf8String(string &str) {
         case 'g':
           switch (charComposing) {
           case '^': // ĝ
-            seq(c4)[1] = '\235';
+            seq(c4, '\235');
             break;
 
           case 'u': // ğ
-            seq(c4)[1] = '\237';
+            seq(c4, '\237');
             break;
 
           case '.': // ġ
-            seq(c4)[1] = '\241';
+            seq(c4, '\241');
             break;
 
           case 'c': // ģ
-            seq(c4)[1] = '\243';
+            seq(c4, '\243');
             break;
 
           default:
@@ -677,7 +678,7 @@ static string &forceUtf8String(string &str) {
 
         case 'h':
           if (charComposing == '^') {
-            seq(c4)[1] = '\245';
+            seq(c4, '\245');
             break;
           } else
             continue;
@@ -685,7 +686,7 @@ static string &forceUtf8String(string &str) {
         case 'j':
           if (charComposing == '^') {
             // ĵ
-            seq(c4)[1] = '\265';
+            seq(c4, '\265');
             break;
           } else
             continue;
@@ -693,7 +694,7 @@ static string &forceUtf8String(string &str) {
         case 'k':
           if (charComposing == 'c') {
             // ķ
-            seq(c4)[1] = '\267';
+            seq(c4, '\267');
             break;
           } else
             continue;
@@ -701,15 +702,15 @@ static string &forceUtf8String(string &str) {
         case 'l':
           switch (charComposing) {
           case '\'': // ĺ
-            seq(c4)[1] = '\272';
+            seq(c4, '\272');
             break;
 
           case 'c': // ļ
-            seq(c4)[1] = '\274';
+            seq(c4, '\274');
             break;
 
           case 'v': // ľ
-            seq(c4)[1] = '\276';
+            seq(c4, '\276');
             break;
 
           default:
@@ -721,19 +722,19 @@ static string &forceUtf8String(string &str) {
         case 'n':
           switch (charComposing) {
           case '~': //  ñ
-            seq(c3)[1] = '\261';
+            seq(c3, '\261');
             break;
 
           case '\'': // ń
-            seq(c5)[1] = '\204';
+            seq(c5, '\204');
             break;
 
           case 'c': // ņ
-            seq(c5)[1] = '\206';
+            seq(c5, '\206');
             break;
 
           case 'v': // ň
-            seq(c5)[1] = '\210';
+            seq(c5, '\210');
             break;
 
           default:
@@ -745,31 +746,31 @@ static string &forceUtf8String(string &str) {
         case 'o':
           switch (charComposing) {
           case '`': // ò
-            seq(c3)[1] = '\262';
+            seq(c3, '\262');
             break;
 
           case '\'': // ó
-            seq(c3)[1] = '\263';
+            seq(c3, '\263');
             break;
 
           case '^': // ô
-            seq(c3)[1] = '\264';
+            seq(c3, '\264');
             break;
 
           case '~': // õ
-            seq(c3)[1] = '\265';
+            seq(c3, '\265');
             break;
 
           case '"': // ö
-            seq(c3)[1] = '\266';
+            seq(c3, '\266');
             break;
 
           case '=': // ō
-            seq(c5)[1] = '\215';
+            seq(c5, '\215');
             break;
 
           case 'u': // ŏ
-            seq(c5)[1] = '\217';
+            seq(c5, '\217');
             break;
 
           default:
@@ -781,15 +782,15 @@ static string &forceUtf8String(string &str) {
         case 'r':
           switch (charComposing) {
           case '\'': // ŕ
-            seq(c5)[1] = '\225';
+            seq(c5, '\225');
             break;
 
           case 'c': // ŗ
-            seq(c5)[1] = '\227';
+            seq(c5, '\227');
             break;
 
           case 'v': // ř
-            seq(c5)[1] = '\230';
+            seq(c5, '\230');
             break;
 
           default:
@@ -801,23 +802,23 @@ static string &forceUtf8String(string &str) {
         case 's':
           switch (charComposing) {
           case 's': // ß
-            seq(c3)[1] = '\237';
+            seq(c3, '\237');
             break;
 
           case '\'': // ś
-            seq(c5)[1] = '\233';
+            seq(c5, '\233');
             break;
 
           case '^': // ŝ
-            seq(c5)[1] = '\235';
+            seq(c5, '\235');
             break;
 
           case 'c': // ş
-            seq(c5)[1] = '\237';
+            seq(c5, '\237');
             break;
 
           case 'v': // š
-            seq(c5)[1] = '\241';
+            seq(c5, '\241');
             break;
 
           default:
@@ -829,11 +830,11 @@ static string &forceUtf8String(string &str) {
         case 't':
           switch (charComposing) {
           case 'c': // ţ
-            seq(c5)[1] = '\243';
+            seq(c5, '\243');
             break;
 
           case 'v': // ť
-            seq(c5)[1] = '\245';
+            seq(c5, '\245');
             break;
 
           default:
@@ -845,39 +846,39 @@ static string &forceUtf8String(string &str) {
         case 'u':
           switch (charComposing) {
           case '`': // ù
-            seq(c3)[1] = '\271';
+            seq(c3, '\271');
             break;
 
           case '\'': // ú
-            seq(c3)[1] = '\272';
+            seq(c3, '\272');
             break;
 
           case '^': // û
-            seq(c3)[1] = '\273';
+            seq(c3, '\273');
             break;
 
           case '"': // ü
-            seq(c3)[1] = '\274';
+            seq(c3, '\274');
             break;
 
           case '~': // ũ
-            seq(c5)[1] = '\251';
+            seq(c5, '\251');
             break;
 
           case '=': // ū
-            seq(c5)[1] = '\253';
+            seq(c5, '\253');
             break;
 
           case 'u': // ŭ
-            seq(c5)[1] = '\255';
+            seq(c5, '\255');
             break;
 
           case 'r': // ů
-            seq(c5)[1] = '\257';
+            seq(c5, '\257');
             break;
 
           case 'k': // ų
-            seq(c5)[1] = '\263';
+            seq(c5, '\263');
             break;
 
           default:
@@ -889,7 +890,7 @@ static string &forceUtf8String(string &str) {
         case 'w':
           if (charComposing == '^') {
             // ŵ
-            seq(c5)[1] = '\265';
+            seq(c5, '\265');
             break;
           } else
             continue;
@@ -897,15 +898,15 @@ static string &forceUtf8String(string &str) {
         case 'y':
           switch (charComposing) {
           case '\'': // ý
-            seq(c3)[1] = '\275';
+            seq(c3, '\275');
             break;
 
           case '"': // ÿ
-            seq(c3)[1] = '\276';
+            seq(c3, '\276');
             break;
 
           case '^': // ŷ
-            seq(c5)[1] = '\267';
+            seq(c5, '\267');
             break;
 
           default:
@@ -917,15 +918,15 @@ static string &forceUtf8String(string &str) {
         case 'z':
           switch (charComposing) {
           case '\'': // ź
-            seq(c5)[1] = '\272';
+            seq(c5, '\272');
             break;
 
           case '.': // ż
-            seq(c5)[1] = '\274';
+            seq(c5, '\274');
             break;
 
           case 'v': // ž
-            seq(c5)[1] = '\276';
+            seq(c5, '\276');
             break;
 
           default:
@@ -937,39 +938,39 @@ static string &forceUtf8String(string &str) {
         case 'A':
           switch (charComposing) {
           case '`': // À
-            seq(c3)[1] = '\200';
+            seq(c3, '\200');
             break;
 
           case '\'': // Á
-            seq(c3)[1] = '\201';
+            seq(c3, '\201');
             break;
 
           case '^': // Â
-            seq(c3)[1] = '\202';
+            seq(c3, '\202');
             break;
 
           case '~': // Ã
-            seq(c3)[1] = '\203';
+            seq(c3, '\203');
             break;
 
           case '"': // Ä
-            seq(c3)[1] = '\204';
+            seq(c3, '\204');
             break;
 
           case 'r': // Å
-            seq(c3)[1] = '\205';
+            seq(c3, '\205');
             break;
 
           case '=': // Ā
-            seq(c4)[1] = '\200';
+            seq(c4, '\200');
             break;
 
           case 'u': // Ă
-            seq(c4)[1] = '\202';
+            seq(c4, '\202');
             break;
 
           case 'k': // Ą
-            seq(c4)[1] = '\204';
+            seq(c4, '\204');
             break;
 
           default:
@@ -982,23 +983,23 @@ static string &forceUtf8String(string &str) {
           switch (charComposing) {
           case 'c':
             // Ç
-            seq(c3)[1] = '\207';
+            seq(c3, '\207');
             break;
 
           case '\'': // Ć
-            seq(c4)[1] = '\206';
+            seq(c4, '\206');
             break;
 
           case '^': // Ĉ
-            seq(c4)[1] = '\210';
+            seq(c4, '\210');
             break;
 
           case '.': // Ċ
-            seq(c4)[1] = '\212';
+            seq(c4, '\212');
             break;
 
           case 'v': // Č
-            seq(c4)[1] = '\214';
+            seq(c4, '\214');
 
           default:
             continue;
@@ -1009,7 +1010,7 @@ static string &forceUtf8String(string &str) {
         case 'D':
           if (charComposing == 'v') {
             // Ď
-            seq(c4)[1] = '\216';
+            seq(c4, '\216');
             break;
           } else
             continue;
@@ -1017,39 +1018,39 @@ static string &forceUtf8String(string &str) {
         case 'E':
           switch (charComposing) {
           case '`': // È
-            seq(c3)[1] = '\210';
+            seq(c3, '\210');
             break;
 
           case '\'': // É
-            seq(c3)[1] = '\211';
+            seq(c3, '\211');
             break;
 
           case '^': // Ê
-            seq(c3)[1] = '\212';
+            seq(c3, '\212');
             break;
 
           case '"': // Ë
-            seq(c3)[1] = '\213';
+            seq(c3, '\213');
             break;
 
           case '=': // Ē
-            seq(c4)[1] = '\222';
+            seq(c4, '\222');
             break;
 
           case 'u': // Ĕ
-            seq(c4)[1] = '\224';
+            seq(c4, '\224');
             break;
 
           case '.': // Ė
-            seq(c4)[1] = '\226';
+            seq(c4, '\226');
             break;
 
           case 'k': // Ę
-            seq(c4)[1] = '\230';
+            seq(c4, '\230');
             break;
 
           case 'v': // Ě
-            seq(c4)[1] = '\232';
+            seq(c4, '\232');
             break;
 
           default:
@@ -1061,19 +1062,19 @@ static string &forceUtf8String(string &str) {
         case 'G':
           switch (charComposing) {
           case '^': // Ĝ
-            seq(c4)[1] = '\234';
+            seq(c4, '\234');
             break;
 
           case 'u': // Ğ
-            seq(c4)[1] = '\236';
+            seq(c4, '\236');
             break;
 
           case '.': // Ġ
-            seq(c4)[1] = '\240';
+            seq(c4, '\240');
             break;
 
           case 'c': // Ģ
-            seq(c4)[1] = '\242';
+            seq(c4, '\242');
             break;
 
           default:
@@ -1085,7 +1086,7 @@ static string &forceUtf8String(string &str) {
         case 'H':
           if (charComposing == '^') {
             // Ĥ
-            seq(c4)[1] = '\244';
+            seq(c4, '\244');
             break;
           } else
             continue;
@@ -1093,23 +1094,23 @@ static string &forceUtf8String(string &str) {
         case 'I':
           switch (charComposing) {
           case '`': // Ì
-            seq(c3)[1] = '\214';
+            seq(c3, '\214');
             break;
 
           case '\'': // Í
-            seq(c3)[1] = '\215';
+            seq(c3, '\215');
             break;
 
           case '^': // Î
-            seq(c3)[1] = '\216';
+            seq(c3, '\216');
             break;
 
           case '"': // Ï
-            seq(c3)[1] = '\217';
+            seq(c3, '\217');
             break;
 
           case '~': // Ĩ
-            seq(c4)[1] = '\250';
+            seq(c4, '\250');
             break;
 
           default:
@@ -1121,7 +1122,7 @@ static string &forceUtf8String(string &str) {
         case 'J':
           if (charComposing == '^') {
             // Ĵ
-            seq(c4)[1] = '\264';
+            seq(c4, '\264');
             break;
           } else
             continue;
@@ -1129,7 +1130,7 @@ static string &forceUtf8String(string &str) {
         case 'K':
           if (charComposing == 'c') {
             // Ķ
-            seq(c4)[1] = '\266';
+            seq(c4, '\266');
             break;
           } else
             continue;
@@ -1137,15 +1138,15 @@ static string &forceUtf8String(string &str) {
         case 'L':
           switch (charComposing) {
           case '\'': // Ĺ
-            seq(c4)[1] = '\271';
+            seq(c4, '\271');
             break;
 
           case 'c': // Ļ
-            seq(c4)[1] = '\273';
+            seq(c4, '\273');
             break;
 
           case 'v': // Ľ
-            seq(c4)[1] = '\275';
+            seq(c4, '\275');
             break;
 
           default:
@@ -1157,19 +1158,19 @@ static string &forceUtf8String(string &str) {
         case 'N':
           switch (charComposing) {
           case '~': // Ñ
-            seq(c3)[1] = '\221';
+            seq(c3, '\221');
             break;
 
           case '\'': // Ń
-            seq(c5)[1] = '\203';
+            seq(c5, '\203');
             break;
 
           case 'c': // Ņ
-            seq(c5)[1] = '\205';
+            seq(c5, '\205');
             break;
 
           case 'v': // Ň
-            seq(c5)[1] = '\207';
+            seq(c5, '\207');
             break;
 
           default:
@@ -1181,31 +1182,31 @@ static string &forceUtf8String(string &str) {
         case 'O':
           switch (charComposing) {
           case '`': // Ò
-            seq(c3)[1] = '\222';
+            seq(c3, '\222');
             break;
 
           case '\'': // Ó
-            seq(c3)[1] = '\223';
+            seq(c3, '\223');
             break;
 
           case '^': // Ô
-            seq(c3)[1] = '\224';
+            seq(c3, '\224');
             break;
 
           case '~': // Õ
-            seq(c3)[1] = '\225';
+            seq(c3, '\225');
             break;
 
           case '"': // Ö
-            seq(c3)[1] = '\226';
+            seq(c3, '\226');
             break;
 
           case '=': // Ō
-            seq(c5)[1] = '\214';
+            seq(c5, '\214');
             break;
 
           case 'u': // Ŏ
-            seq(c5)[1] = '\216';
+            seq(c5, '\216');
             break;
 
           default:
@@ -1217,15 +1218,15 @@ static string &forceUtf8String(string &str) {
         case 'R':
           switch (charComposing) {
           case '\'': // Ŕ
-            seq(c5)[1] = '\224';
+            seq(c5, '\224');
             break;
 
           case 'c': // Ŗ
-            seq(c5)[1] = '\226';
+            seq(c5, '\226');
             break;
 
           case 'v': // Ř
-            seq(c5)[1] = '\230';
+            seq(c5, '\230');
             break;
 
           default:
@@ -1237,19 +1238,19 @@ static string &forceUtf8String(string &str) {
         case 'S':
           switch (charComposing) {
           case '\'': // Ś
-            seq(c5)[1] = '\232';
+            seq(c5, '\232');
             break;
 
           case '^': // Ŝ
-            seq(c5)[1] = '\234';
+            seq(c5, '\234');
             break;
 
           case 'c': // Ş
-            seq(c5)[1] = '\236';
+            seq(c5, '\236');
             break;
 
           case 'v': // Š
-            seq(c5)[1] = '\240';
+            seq(c5, '\240');
             break;
 
           default:
@@ -1261,11 +1262,11 @@ static string &forceUtf8String(string &str) {
         case 'T':
           switch (charComposing) {
           case 'c': // Ţ
-            seq(c5)[1] = '\242';
+            seq(c5, '\242');
             break;
 
           case 'v': // Ť
-            seq(c5)[1] = '\244';
+            seq(c5, '\244');
             break;
 
           default:
@@ -1277,39 +1278,39 @@ static string &forceUtf8String(string &str) {
         case 'U':
           switch (charComposing) {
           case '`': // Ù
-            seq(c3)[1] = '\231';
+            seq(c3, '\231');
             break;
 
           case '\'': // Ú
-            seq(c3)[1] = '\232';
+            seq(c3, '\232');
             break;
 
           case '^': // Û
-            seq(c3)[1] = '\233';
+            seq(c3, '\233');
             break;
 
           case '"': // Ü
-            seq(c3)[1] = '\234';
+            seq(c3, '\234');
             break;
 
           case '~': // Ũ
-            seq(c5)[1] = '\250';
+            seq(c5, '\250');
             break;
 
           case '=': // Ū
-            seq(c5)[1] = '\252';
+            seq(c5, '\252');
             break;
 
           case 'u': // Ŭ
-            seq(c5)[1] = '\254';
+            seq(c5, '\254');
             break;
 
           case 'r': // Ů
-            seq(c5)[1] = '\256';
+            seq(c5, '\256');
             break;
 
           case 'k': // Ų
-            seq(c5)[1] = '\262';
+            seq(c5, '\262');
             break;
 
           default:
@@ -1321,7 +1322,7 @@ static string &forceUtf8String(string &str) {
         case 'W':
           if (charComposing == '^') {
             // Ŵ
-            seq(c5)[1] = '\264';
+            seq(c5, '\264');
             break;
           } else
             continue;
@@ -1329,15 +1330,15 @@ static string &forceUtf8String(string &str) {
         case 'Y':
           switch (charComposing) {
           case '\'': // Ý
-            seq(c3)[1] = '\235';
+            seq(c3, '\235');
             break;
 
           case '^': // Ŷ
-            seq(c5)[1] = '\266';
+            seq(c5, '\266');
             break;
 
           case '"': // Ÿ
-            seq(c5)[1] = '\270';
+            seq(c5, '\270');
             break;
 
           default:
@@ -1349,15 +1350,15 @@ static string &forceUtf8String(string &str) {
         case 'Z':
           switch (charComposing) {
           case '\'': // Ź
-            seq(c5)[1] = '\271';
+            seq(c5, '\271');
             break;
 
           case '.': // Ż
-            seq(c5)[1] = '\273';
+            seq(c5, '\273');
             break;
 
           case 'v': // Ž
-            seq(c5)[1] = '\275';
+            seq(c5, '\275');
             break;
 
           default:
